Coverage for tasks/tests/bmi_tests.py: 38%

1"""

2 camcops_server/tasks/tests/bmi_tests.py

3

4===============================================================================

5

6 Copyright (C) 2012, University of Cambridge, Department of Psychiatry.

7 Created by Rudolf Cardinal (rnc1001@cam.ac.uk).

8

9 This file is part of CamCOPS.

10

11 CamCOPS is free software: you can redistribute it and/or modify

12 it under the terms of the GNU General Public License as published by

13 the Free Software Foundation, either version 3 of the License, or

14 (at your option) any later version.

15

16 CamCOPS is distributed in the hope that it will be useful,

17 but WITHOUT ANY WARRANTY; without even the implied warranty of

18 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the

19 GNU General Public License for more details.

20

21 You should have received a copy of the GNU General Public License

22 along with CamCOPS. If not, see <https://www.gnu.org/licenses/>.

23

24===============================================================================

25

26"""

27

28 from unittest import TestCase

29

30 from camcops_server.tasks.bmi import Bmi

31

32

33 class BmiTests(TestCase):

34 def test_bmi_calculation_for_healthy_mass_and_height(self):

35 bmi = Bmi()

36

37 bmi.mass_kg = 70.0

38 bmi.height_m = 1.83

39

40 self.assertAlmostEqual(bmi.bmi(), 20.902, places=3)

41

42 def test_bmi_none_for_zero_height(self):

43 bmi = Bmi()

44

45 bmi.mass_kg = 70.0

46 bmi.height_m = 0

47

48 self.assertIsNone(bmi.bmi())

49

50 def test_bmi_none_when_not_complete(self):

51 bmi = Bmi()

52

53 self.assertIsNone(bmi.bmi())